const queryLimit = 10000
const query = `PREFIX wgs84: <http://www.w3.org/2003/01/geo/wgs84_pos#>
PREFIX geo: <http://www.opengis.net/ont/geosparql#>
PREFIX gn: <http://www.geonames.org/ontology#>
PREFIX rdf: <http://www.w3.org/1999/02/22-rdf-syntax-ns#>
PREFIX rdfs: <http://www.w3.org/2000/01/rdf-schema#>
PREFIX rdf: <http://www.w3.org/1999/02/22-rdf-syntax-ns#>
PREFIX dc: <http://purl.org/dc/elements/1.1/>
PREFIX dct: <http://purl.org/dc/terms/>
PREFIX skos: <http://www.w3.org/2004/02/skos/core#>
PREFIX edm: <http://www.europeana.eu/schemas/edm/>
PREFIX foaf: <http://xmlns.com/foaf/0.1/>

# let op: geeft aantal van unieke combinaties van ?date en ?landLabel
SELECT ?landLabel ?lat ?long ?date (COUNT(?cho) AS ?choCount) WHERE {
   ?cho dct:created ?date;
        dct:spatial ?plaats .
 # We willen geen datums die de string [NI] bevatten
   FILTER (!REGEX(?date, "[NI]")) . #zorgt ervoor dat de string "NI" niet wordt meegenomen
 # geef het label van het land waar de plaats ligt en de lat/long van het land
   ?plaats skos:exactMatch/gn:parentCountry ?land .
   ?land wgs84:lat ?lat .
   ?land wgs84:long ?long .
   ?land gn:name ?landLabel .
} GROUP BY ?date ?landLabel ?lat ?long
ORDER BY DESC(?choCount)`
//Please use your own endpoint when using this 
const endpoint = "https://api.data.netwerkdigitaalerfgoed.nl/datasets/ivo/NMVW/services/NMVW-14/sparql"
const  dataSource = 'https://gist.githubusercontent.com/Razpudding/f34e3dcabb5b950f468a68077cefda96/raw/a5a85adf3562e24e17a993c989f61ffcc9ecb2a1/surveyData.csv'

makeVisualization()

// Our main function which runs other function to make a visualization
async function makeVisualization(){
  //Wait for the promise to resolve with the data
  let data = await loadData(endpoint, query)
  console.log("rawData: ", data)
  
	data = data.map(cleanData)
  console.log("cleanedData: ", data)
	
	data = transformData(data)
  console.log("transformedData: ", data)
  
  console.log(data)
}

//Load the data and return a promise which resolves with said data
function loadData(url, query){
  return d3.json(endpoint +"?query="+ encodeURIComponent(query) + "&format=json")
    .then(data => data.results.bindings)
}

//Nest the data per country
function transformData(source){
  let transformed =  d3.nest()
		.key(function(d) { return d.landLabel; })
		.entries(source);
    transformed.forEach(country => {
      country.amount = country.values.length
    })
  return transformed
}

//This function gets the nested value out of the object in each property
// in our data
function cleanData(row){
   let result = {}
    Object.entries(row)
    	.forEach(([key, propValue]) => { 		
				result[key] = propValue.value
  	})
   return result
}